c23456789012345678901234567890123456789012345678901234567890123456789012
c
c  Forced convection of PTT fluid in fully-developed laminar annular flow
c  for imposed constant wall heat fluxes (asymmetric fluxes), in the 
c  presence of viscous dissipation.
c
c  Input data are: radius ratio, Brinkman number, heat flux ratio and Epsilon*We*We
c  radial position (for the temperature)
c
c  Output data are integral quantities such as: inner wall Nusselt number
c  Outer wall Nussselt number, bulk (or mixing) temperature and inner wall
c  temperature
c
c  11th November 2005  Fernando Pinho and Paulo Coelho
c  CEFT- Centro de Estudos de Fenmenos de Transporte
c
       program PTTanularheat
       IMPLICIT REAL*8(A-H,O-Z,k)
       COMMON ALAMCA,PSI,PHI,OMEGA,BETA,X,YY,ya,c1


       OPEN (5,FILE='INPUTPTTAN.DAT')
       REWIND(5)
       READ(5,*) EPS,WE			!Epsilon,Weissenberg number
       READ(5,*) k,BRFIRST,BRLAST	!radius ratio, first and last Brinkman number
       READ(5,*) q0qifirst,q0qilast		!first and last radius ratio
       CLOSE(5)

       ewe=EPS*WE*WE			!Epsilon*We**2  
       YY=k/(1.-k)			!Y 
       yin=1.				!y+inner
       yout=1./k			!y+outer
c       
c   Determination of ystarplus (ya) (the zero shear stress location) and X
c   This is an iterative calculation because ystarplus depends on X
c   and X depends on ystarplus
c
       XN= 1./((1.+k*k)/(1.-k)**2-(1.+k)/(1.-k)*(1./DLOG(1./k)))     
       X=XN			!initial value of X
       XX=1.D-10		!initially a very small value
c        write(*,*)'XN=',XN 
	
 1     CONTINUE
       IF (DABS(XX-X)/XX .GT. 1.D-4) THEN
       X=XX
       Wec=We*X
       a1=6.*DLOG(k)/(1.-k*k)/(1./k-1.)/(1./k-1.)
       a2=3.*k*k/(1.-k)/(1.-k)/(1.-k)/(1.-k)-2.*DLOG(k)/(32.*EPS*Wec*
     1    Wec*(1.-k)*(1.-k)*(1./k/k-1.))
       a3=-k*k/(1.-k)/(1.-k)/(1.-k)/(1.-k)*(1./(32.*EPS*Wec*Wec)+
     1    (1.+k*k)/2./(1.-k)/(1.-k))
       a=a2-a1*a1/3.
       b=a3-a1*a2/3.+2.*a1*a1*a1/27.
       d=b*b/4.+a*a*a/27.
       pA=-b/2.+DSQRT(d)
       qA=-b/2.-DSQRT(d)
       yPOs=DSQRT(pA/DABS(pA)*(DABS(pA))**(1./3.)+qA/DABS(qA)*
     1         (DABS(qA))**(1./3.)-a1/3.)

       AI1=DLOG(1./k)/2./(k-1.)/(k-1.)+(k+1.)*(2*yPOs**2*(k-1.)-k-1.)/
     1     (8.*yPOs**2*(k-1.)*(k-1.))
       AI2=(yPOs*yPOs/2.+3./2./(k-1.)/(k-1.))*DLOG(1./k)+((1.+k)*
     1   (6.*yPOs**6.*(k-1.)**5+18.*yPOs**4*k*k*(k-1.)**3-9*yPOs**2*
     1    k*k*(k-1.)**2*(k+1.)+k*k*(k+1)*(2*k*k+1.)))/
     1     (24.*yPOs*yPOs*yPOs*yPOs*k*k*(k-1.)**4)
       ALFA=AI1*yPOs*yPOs*8.*(1.-k)/(1.+k)
       BETA1=-32.*ewe*yPOs*yPOs*yPOs*yPOs*AI2*8.*(1.-k)/(1.+k)
       DD=DSQRT(4.*ALFA*ALFA*ALFA+27.*BETA1)+3.**(3./2.)*DSQRT(BETA1)
       XX=432.**(1./6.)*(DD**(2./3.)-2.**(2./3.)*ALFA)/6./DSQRT(BETA1)
     1   /DD**(1./3.)
c       write(*,*)'XX=',XX,'yPOs=',yPOs
c       pause
       GOTO 1
       ELSE
        X=XX
        ya=yPOs*(1.-k)/k
       END IF
c   End of calculation of ystarplus and X

c       write(*,*)'XN=',XN,'X=',X
c       write(*,*)'ya=',ya
c       pause



c   Calculation of various parameters and constants
       
       ALAMCA=2.*X*k*k*ya*ya*(96.*X*X*ewe*k*k*ya*ya-k*k+2.*k-1.)/
     1         (k-1.)/(k-1.)/(k-1.)/(k-1.)	!Capital Lambda
       PHI=32.*X*X*X*ewe*k*k*k*k*ya*ya*ya*ya/(k-1.)/(k-1.)/(k-1.)/(k-1.)
       c1=-2.*ALAMCA*DLOG(1.-k)+2.*PHI*k*k*ya*ya-ALAMCA/k/k/(ya*ya)+
     1    PHI/(k*k*k*k*ya*ya*ya*ya)
       OMEGA=32.*ewe*X*X*YY*YY*ya*ya
       write(*,*)'ALAMCA=',ALAMCA,'PHI=',PHI,'c1=',c1
       write(*,*)
       write(*,*)'**** W A I T ******'
       
     
       
       npoints=50		!50 points across the annulus
       dely=(yout-yin)/npoints	

       OPEN (10,FILE='OUTPTTAN_BR.DAT')	!Output file for varying Brinkman number
       REWIND(10)
       OPEN (11,FILE='OUTPTTAN_Q.DAT')	!Output file for varying heat flux ratio
       REWIND(11)
       OPEN (15,FILE='OUTPTTTEMP.DAT')	!Output of temperature profile
       REWIND(15)
       
       
c       NBR=DINT(DLOG(BRLAST))-DINT(DLOG(BRFIRST))+1
c       Nq0qi=DINT(DLOG(q0qilast))-DINT(DLOG(q0qifirst))+1
       		       
      
c  Beginning of calculations. First, we fix Brinkman and run various q0qi

c  TO begin with the special case of Br=0
       br=0.

      WRITE(11,'(3G17.8)') 'Brinkman= ',br,'k=',k,'EpsWe**2=',ewe
      WRITE(11,*)'     q0qi  ','         Nui     ','          Nuo    ',
     & '        Tbulk    ','        Twi   '

      DO J=DINT(DLOG10(q0qifirst)),DINT(DLOG10(q0qilast))

      DO JJ=0,8
       aux=10.**(J)
       q0qi=aux*(1+JJ)
       WRITE(11,'(5G17.8)') q0qi,UNui(k,q0qi,br),UNuo(k,q0qi,br),
     &  Tbulk(k,q0qi,br),Twi(k,q0qi,br)
          WRITE(15,'(4G17.8)') 'Brinkman=',br,'k=',k,'q0qi=',q0qi,
     &     'EpsWe**2=',ewe
             WRITE(15,*) '     y  ','      Temperature   '
             DO LL=0,npoints	!Produce temperature profile
	      y=yin+LL*dely
	      WRITE(15,'(2G17.8)') y,Temp(k,q0qi,br,y)
	     END DO
             WRITE(15,*)
             WRITE(15,*)
      END DO
      END DO
       WRITE(11,*)
       WRITE(11,*)

c  Now the other Brinkman numbers, both positive and negative

      DO ISIGN=1,2
       DO I=DINT(DLOG10(BRFIRST)),DINT(DLOG10(BRLAST))
       br=(-1)**ISIGN*10.**(I)

       WRITE(11,'(3G17.8)') 'Brinkman= ',br,'k=',k,'EpsWe**2=',ewe
      WRITE(11,*)'     q0qi  ','         Nui     ','          Nuo    ',
     & '        Tbulk    ','        Twi   '

       DO J=DINT(DLOG10(q0qifirst)),DINT(DLOG10(q0qilast))

       DO JJ=0,8
        aux=10.**(J)
        q0qi=aux*(1+JJ)
        WRITE(11,'(5G17.8)') q0qi,UNui(k,q0qi,br),UNuo(k,q0qi,br),
     &   Tbulk(k,q0qi,br),Twi(k,q0qi,br)
        WRITE(15,'(4G17.8)') 'Brinkman=',br,'k=',k,'q0qi=',q0qi,
     &   'EpsWe**2=',ewe
             WRITE(15,*) '     y  ','      Temperature   '
             DO LL=0,npoints	!Produce temperature profile
	      y=yin+LL*dely
	      WRITE(15,'(2G17.8)') y,Temp(k,q0qi,br,y)
	     END DO
             WRITE(15,*)
             WRITE(15,*)
       END DO
       END DO
        WRITE(11,*)
        WRITE(11,*)
       END DO
      END DO

c End

c  Now we fix the heat flux ratio and run various Brinkman numbers
c
c  To begin with the special case of isolated outer wall q0qi=0

       q0qi=0.

      WRITE(10,'(3G17.8)') 'Heat flux ratio= ',q0qi,'k=',k,'EpsWe**2=',
     &   ewe
      WRITE(10,*)'     br    ','         Nui     ','          Nuo    ',
     & '        Tbulk    ','        Twi   '

      DO ISIGN=1,2
         IF (ISIGN.EQ.1) THEN
          J1=DINT(DLOG10(BRLAST))
	  J2=DINT(DLOG10(BRFIRST))
	  JSTEP=-1
         ELSE
          J1=DINT(DLOG10(BRFIRST))
          J2=DINT(DLOG10(BRLAST))
	  JSTEP=1
         END IF
       DO J=J1,J2,JSTEP
         IF (ISIGN.EQ.1) THEN
          JJ1=8
	  JJ2=0
	  JJSTEP=-1
         ELSE
          JJ1=0
          JJ2=8
	  JJSTEP=1
         END IF
        
       DO JJ=JJ1,JJ2,JJSTEP
        aux=10.**(J)
        br=(-1)**ISIGN*aux*(1+JJ)
        WRITE(10,'(5G17.8)') br,UNui(k,q0qi,br),UNuo(k,q0qi,br),
     &   Tbulk(k,q0qi,br),Twi(k,q0qi,br)
       END DO
       END DO
        WRITE(10,*)
        WRITE(10,*)
       END DO

c  Now the other q0qi cases

      DO I=DINT(DLOG10(q0qifirst)),DINT(DLOG10(q0qilast))
       q0qi=10.**(I)

      WRITE(10,'(3G17.7)') 'Heat flux ratio= ',q0qi,'k=',k,'EpsWe**2=',
     &  ewe
      WRITE(10,*)'     br    ','         Nui     ','          Nuo    ',
     & '        Tbulk    ','        Twi   '

      DO ISIGN=1,2
         IF (ISIGN.EQ.1) THEN
          J1=DINT(DLOG10(BRLAST))
	  J2=DINT(DLOG10(BRFIRST))
	  JSTEP=-1
         ELSE
          J1=DINT(DLOG10(BRFIRST))
          J2=DINT(DLOG10(BRLAST))
	  JSTEP=1
         END IF

       DO J=J1,J2,JSTEP
         IF (ISIGN.EQ.1) THEN
          JJ1=80		!if using 8*10**i don't forget to divide by 10**i below. Improves resolution
	  JJ2=0
	  JJSTEP=-1
         ELSE
          JJ1=0
          JJ2=80		!if using 8*10**i don't forget to divide by 10**i below. Improves resolution
	  JJSTEP=1
         END IF

       DO JJ=JJ1,JJ2,JJSTEP
        aux=10.**(J)
        br=(-1.)**ISIGN*aux*(1+JJ/10.)		!Division by 10**i below because of (see above)
        WRITE(10,'(5G17.8)') br,UNui(k,q0qi,br),UNuo(k,q0qi,br),
     &   Tbulk(k,q0qi,br),Twi(k,q0qi,br)
       END DO
       END DO
        WRITE(10,*)
        WRITE(10,*)
       END DO
       END DO
c  end of all
      CLOSE(10)
      CLOSE(11)
      CLOSE(12)


      END


c  Definition of the various functions



       REAL*8 FUNCTION UNui(k,q0qi,br)
       IMPLICIT REAL*8(A-H,O-Z,k)
       COMMON ALAMCA,PSI,PHI,OMEGA,BETA,X,YY,ya,c1
c        COMMON Tbulk,Twi
      
c determination of inner walll Nusselt number
c

      UNui=(1.+k)/(k+q0qi)/(Twi(k,q0qi,br)-Tbulk(k,q0qi,br))
      
     
      RETURN
      END
     
     
       REAL*8 FUNCTION UNuo(k,q0qi,br)
       IMPLICIT REAL*8(A-H,O-Z,k)
       COMMON ALAMCA,PSI,PHI,OMEGA,BETA,X,YY,ya,c1
c        COMMON Tbulk,Twi
c     
c determination of outer walll Nusselt number
c
c     
      UNuo=q0qi*(1.+k)/(k+q0qi)/(0.-Tbulk(k,q0qi,br))
     
      RETURN
      END
      
       REAL*8 FUNCTION Tbulk(k,q0qi,br)
       IMPLICIT REAL*8(A-H,O-Z,k)
       COMMON ALAMCA,PSI,PHI,OMEGA,BETA,X,YY,ya,c1
c determination of temperature profile

       BETA=16.*br*ya*ya*X*X*YY*YY*YY*YY
       PSI=YY*YY*(1.+8.*X*br)
c determination of bulk temperature
c
c          
      c3=-ALAMCA*PSI*DLOG(k)*DLOG(1-k)-ALAMCA*PSI*DLOG(1-k)/(2*k**2)+PHI
     $*PSI*ya*ya*DLOG(k)**2+beta*ya*ya*(1-4*OMEGA)*DLOG(k)**2/2+ALAMCA
     $*PSI*DLOG(k)**2+PHI*PSI*DLOG(k)/(6*ya**4)-OMEGA*BETA*
     $ya**4*DLOG(k)/2-(ALAMCA*PSI+beta*(4*OMEGA-1))*DLOG(k)/(4*ya*ya)+
     $OMEGA*beta*DLOG(k)/(6*ya**4)+(q0qi*(1-q0qi)*DLOG(k)/(2*(q0qi+1)*
     $(k+q0qi))+DLOG(k)/((q0qi+1)*(k-1))-(ALAMCA*PSI-6*OMEGA*beta+PSI
     $*c1+2*beta-1)*DLOG(k)/2)+PHI*PSI/(36*k**6*ya**4)+OMEGA*beta*k**2*
     $ya**4/4-(ALAMCA*PSI+beta*(4*OMEGA-1))/(16*k**4*ya**2)+OMEGA*beta/
     $(36*k**6*ya**4)-(2*ALAMCA*PSI-6*OMEGA*beta+PSI*c1+2*beta)/(4*k**2)

      c2=-ALAMCA*PSI*DLOG((1-k)/k)+PHI*PSI/(6*ya**4)-OMEGA*beta*ya**4/
     $2-(ALAMCA*PSI+beta*(4*OMEGA-1))/(4*ya**2)+OMEGA*beta/(6*ya**4)-
     $ALAMCA*PSI/2+(q0qi*(1-q0qi)/(2*(q0qi+1)*(k+q0qi))+1/
     $((q0qi+1)*(k-1))+(6*OMEGA*beta-PSI*c1-2*beta+1)/2)


      Tbulk=ALAMCA**2*PSI*(k**2+1)*DLOG(1-k)**2/(2*k**2)+ALAMCA*ya**2*(2
     $*PHI*PSI-beta*(4*OMEGA-1))*DLOG(k)**2*DLOG(1-k)/(k**2-1)+ALAMCA*
     $OMEGA*beta*k**2*ya**4*DLOG(k)*DLOG(1-k)/(1-k**2)+ALAMCA*ya**2*(2*
     $PHI*PSI-beta*(4*OMEGA-1))*DLOG(k)*DLOG(1-k)/(k**2-1)+ALAMCA*(ALAM
     $CA*PSI*k**2-2*c2)*DLOG(k)*DLOG(1-k)/(1-k**2)-ALAMCA*ya**2*(4*PHI
     $*PSI-4*OMEGA*beta+beta)*DLOG(1-k)/2+ALAMCA*(k**4+k**2+1)*(5*ALAMCA
     $*PSI+beta*(4*OMEGA-1))*DLOG(1-k)/(24*k**4*ya**2)-ALAMCA*(k**6+k**4
     $+k**2+1)*(10*PHI*PSI+OMEGA*beta)*DLOG(1-k)/(72*k**6*ya**4)+ALAMCA
     $*(3*ALAMCA*PSI*(k**2+1)-2*(3*OMEGA*beta*(k**2+1)-PSI*c1*(k**2+1)-
     $beta*(k**2+1)+2*k**2*(c2-2*c3)))*DLOG(1-k)/(4*k**2)+2*PHI*k**2*y
     $a**4*(2*PHI*PSI-beta*(4*OMEGA-1))*DLOG(k)**3/(3*(k**2-1))+ALAMCA
     $*OMEGA*beta*k**2*ya**4*DLOG(k)**2/(2*(k**2-1))+ya**2*(2*PHI*(ALAM
     $CA*PSI+PSI*c1+2*c2*k**2)+beta*(1-4*OMEGA)*(ALAMCA+c1))*DLOG(k)**2
     $/(2*(k**2-1))+PHI*(2*PHI*PSI-beta*(4*OMEGA-1))*DLOG(k)**2/(6*k
     $**4*ya**2*(1-k**2))+ALAMCA*(2*PHI*PSI+2*ALAMCA*PSI*k**4-beta*(4*
     $OMEGA-1))*DLOG(k)**2/(4*k**2*(k**2-1))+OMEGA*beta*c1*k**2*ya**4*DL
     $OG(k)/(2*(1-k**2))+ya**2*(2*PHI*(2*ALAMCA*PSI*(k**2+1)+PSI*c1-4*
     $c3*k**2)+beta*(1-4*OMEGA)*(ALAMCA*(k**2+2)+c1))*DLOG(k)/(2*(k**2-1
     $))+(8*PHI**2*PSI+4*PHI*beta*(1-4*OMEGA)+3*ALAMCA*k**2*(5*ALAMCA
     $*PSI*k**4+4*OMEGA*beta*k**4-beta*k**4-12*c2))*DLOG(k)/(72*k**4*ya
     $**2*(1-k**2))+(2*PHI*(5*ALAMCA*PSI*k**6-12*c2)+ALAMCA*OMEGA*beta
     $*k**6)*DLOG(k)/(72*k**4*ya**4*(k**2-1))+(2*PHI*ALAMCA*PSI-6*ALAMCA
     $**2*PSI*k**4+ALAMCA*(4*OMEGA*beta*(3*k**4-1)-4*PSI*c1*k**4+beta*
     $(1-4*k**4)+8*k**2*(c2*(k**2+1)-2*c3*k**2))+8*c1*c2*k**2)*DLOG(k)/(
     $8*k**2*(k**2-1))+PHI*OMEGA*beta*k**2*ya**6/2+ya**2*(beta*(ALAMCA
     $*(11*OMEGA-3)+c1*(4*OMEGA-1))-4*PHI*(3*ALAMCA*PSI-3*OMEGA*beta+P
     $SI*c1+beta))/4+(16*PHI**2*PSI*(k**4+k**2+1)+4*PHI*beta*(k**4+k
     $**2+1)*(1-2*OMEGA)+3*(29*ALAMCA**2*PSI*(k**4+k**2+1)-ALAMCA*(68*OM
     $EGA*beta*(k**4+k**2+1)-15*PSI*c1*(k**4+k**2+1)-23*beta*(k**4+k**2+
     $1)+18*k**2*(c2-4*c3)*(k**2+1))+3*beta*c1*(k**4+k**2+1)*(4*OMEGA-1)
     $))/(432*k**4*ya**2)+((k**6+k**4+k**2+1)*(9*ALAMCA**2*PSI+ALAMCA*be
     $ta*(35*OMEGA-9)-4*OMEGA*beta*c1)-2*PHI*(41*ALAMCA*PSI*(k**6+k**4
     $+k**2+1)-4*(27*OMEGA*beta*(k**6+k**4+k**2+1)-5*PSI*c1*(k**6+k**4+k
     $**2+1)-9*beta*(k**6+k**4+k**2+1)+4*k**2*(c2-6*c3)*(k**4+k**2+1))))
     $/(576*k**6*ya**4)-(k**8+k**6+k**4+k**2+1)*(PHI*(13*ALAMCA*PSI+9*
     $beta*(4*OMEGA-1))+4*ALAMCA*OMEGA*beta)/(720*k**8*ya**6)+PHI*(k**
     $10+k**8+k**6+k**4+k**2+1)*(PHI*PSI+OMEGA*beta)/(216*k**10*ya**8)
     $-(2*PSI*(k**2+1)*(2*PHI*ALAMCA-3*ALAMCA**2-6*ALAMCA*c1-2*c1**2)+
     $2*PHI*beta*(k**2+1)*(2*OMEGA-1)+ALAMCA*(8*OMEGA*beta*(k**2+1)-3*
     $beta*(k**2+1)+32*k**2*(c2-c3))+8*c1*(3*OMEGA*beta*(k**2+1)-beta*(k
     $**2+1)+2*k**2*(c2-2*c3)))/(32*k**2)
     
      RETURN
      END

       REAL*8 FUNCTION Twi(k,q0qi,br)
       IMPLICIT REAL*8(A-H,O-Z,k)
       COMMON ALAMCA,PSI,PHI,OMEGA,BETA,X,YY,ya,c1

       BETA=16.*br*ya*ya*X*X*YY*YY*YY*YY
       PSI=YY*YY*(1.+8.*X*br)

c     
c determination of inner wall temperature
c
c          
      c3=-ALAMCA*PSI*DLOG(k)*DLOG(1-k)-ALAMCA*PSI*DLOG(1-k)/(2*k**2)+PHI
     $*PSI*ya*ya*DLOG(k)**2+beta*ya*ya*(1-4*OMEGA)*DLOG(k)**2/2+ALAMCA
     $*PSI*DLOG(k)**2+PHI*PSI*DLOG(k)/(6*ya**4)-OMEGA*BETA*
     $ya**4*DLOG(k)/2-(ALAMCA*PSI+beta*(4*OMEGA-1))*DLOG(k)/(4*ya*ya)+
     $OMEGA*beta*DLOG(k)/(6*ya**4)+(q0qi*(1-q0qi)*DLOG(k)/(2*(q0qi+1)*
     $(k+q0qi))+DLOG(k)/((q0qi+1)*(k-1))-(ALAMCA*PSI-6*OMEGA*beta+PSI
     $*c1+2*beta-1)*DLOG(k)/2)+PHI*PSI/(36*k**6*ya**4)+OMEGA*beta*k**2*
     $ya**4/4-(ALAMCA*PSI+beta*(4*OMEGA-1))/(16*k**4*ya**2)+OMEGA*beta/
     $(36*k**6*ya**4)-(2*ALAMCA*PSI-6*OMEGA*beta+PSI*c1+2*beta)/(4*k**2)

      Twi=ALAMCA*PSI*DLOG((1.-k)/k)/2.-PHI*PSI/(36.*ya**4.)+PSI*c1/4.+
     $c3+ALAMCA*PSI*(8.*ya*ya+1.)/(16.*ya*ya)-beta*(4.*OMEGA*(9.*ya**8.+
     $54.*ya**4.-9.*ya*ya+1.)-9.*ya*ya*(8.*ya*ya-1.))/(144.*ya**4.)


      RETURN
      END


       REAL*8 FUNCTION Temp(k,q0qi,br,y)
       IMPLICIT REAL*8(A-H,O-Z,k)
       COMMON ALAMCA,PSI,PHI,OMEGA,BETA,X,YY,ya,c1
c determination of temperature profile

       beta=16.*br*ya*ya*X*X*YY*YY*YY*YY
       PSI=YY*YY*(1.+8.*X*br)

      c3=-ALAMCA*PSI*DLOG(k)*DLOG(1-k)-ALAMCA*PSI*DLOG(1-k)/(2*k**2)+PHI
     $*PSI*ya*ya*DLOG(k)**2+beta*ya*ya*(1-4*OMEGA)*DLOG(k)**2/2+ALAMCA
     $*PSI*DLOG(k)**2+PHI*PSI*DLOG(k)/(6*ya**4)-OMEGA*beta*
     $ya**4*DLOG(k)/2-(ALAMCA*PSI+beta*(4*OMEGA-1))*DLOG(k)/(4*ya*ya)+
     $OMEGA*beta*DLOG(k)/(6*ya**4)+(q0qi*(1-q0qi)*DLOG(k)/(2*(q0qi+1)*
     $(k+q0qi))+DLOG(k)/((q0qi+1)*(k-1))-(ALAMCA*PSI-6*OMEGA*beta+PSI
     $*c1+2*beta-1)*DLOG(k)/2)+PHI*PSI/(36*k**6*ya**4)+OMEGA*beta*k**2*
     $ya**4/4-(ALAMCA*PSI+beta*(4*OMEGA-1))/(16*k**4*ya**2)+OMEGA*beta/
     $(36*k**6*ya**4)-(2*ALAMCA*PSI-6*OMEGA*beta+PSI*c1+2*beta)/(4*k**2)

      c2=-ALAMCA*PSI*DLOG((1-k)/k)+PHI*PSI/(6*ya**4)-OMEGA*beta*ya**4/
     $2-(ALAMCA*PSI+beta*(4*OMEGA-1))/(4*ya**2)+OMEGA*beta/(6*ya**4)-
     $ALAMCA*PSI/2+(q0qi*(1-q0qi)/(2*(q0qi+1)*(k+q0qi))+1/
     $((q0qi+1)*(k-1))+(6*OMEGA*beta-PSI*c1-2*beta+1)/2)

      temp=(2*c2-ALAMCA*PSI*y*y)*DLOG(y)/2+ALAMCA*PSI*y*y*DLOG((1-k)/k)
     $/2+ya*ya*(beta*(4*OMEGA-1)-2*PHI*PSI)*DLOG(y)**2/2-y**6*(PHI*PSI
     $+OMEGA*beta)/(36*ya**4)+y**4*(ALAMCA*PSI+beta*(4*OMEGA-1))/(16*ya
     $*ya)+y*y*(2*ALAMCA*PSI-6*OMEGA*BETA+PSI*c1+2*beta)/4-OMEGA*beta*y
     $a**4/(4*y*y)+c3
      
      RETURN
      END


